<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Photoramas_params_model extends Model
{    
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_file_base_path = PHOTOREP;
    private $_file_ext = INCEXT;
    private $_file_id = 0;
    private $_file_prefix = 'params_';
    private $_file_path = '';

    private $_params = array(
        'max_per_gal'  => '10',      // Nombre maximum de miniatures par galerie
        'width_max'    => '100',     // Largeur maximum d'une miniature
        'height_max'   => '75',      // Hauteur maximum d'une miniature
        'display_mode' => 'lytebox', // Mode d'affichage pour le photorama
        'delta_time'   => '0',       // Intervalle de temps (en seconde) pour l'affichage entre deux diapos
        'max_per_row'  => '5',       // Nombre maximum de miniatures par ligne
        'space'        => '20',      // Espace en pixels entre les miniatures
        'position'     => 'L',       // Position des miniatures L / C / R
        'slideshow'    => '',        // Inclure dans la boite slideshow on/off
        'free_gal'     => '',        // Galerie indépendante on/off
    );

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct($file_id = 0)
	{
        $this -> set_file_path($file_id); 
	}

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie le chemin du fichier qui contient la base de données des diapos enregistrées dana le photorama
     * 
     * @access public 
	 * @param integer Identifiant du photorama
	 * @return string chemin du fichier qui contient la base de données des diapos enregistrées dana le photorama
	 */
    public function set_file_path($file_id)
	{
        if (!empty($file_id) && ctype_digit((string) $file_id)) {
            $dir_file_path = $this -> _file_base_path.'gal_'.$file_id;
            
            if (is_dir($dir_file_path)) {
                $this -> _file_path = $dir_file_path.'/'.$this -> _file_prefix.$file_id.$this -> _file_ext;
                $this -> _file_id = $file_id;               
            }
        }
        
        return $this -> _file_path;
	}

	// --------------------------------------------------------------------
 
	/**
	 * Récupère et renvoie dans un tableau les paramètres enregistrés du photorama
     * 
     * @access public 
	 * @param integer Identifiant du photorama (optionnel)
	 * @return array Tableau contenant les valeurs des paramètres enregistrés du photorama (par défaut $this -> _params)
	 */
    public function read($file_id = 0)
    {        
        $this -> set_file_path($file_id);    
        
        $data = array_merge($this -> _params, $this -> _read());
        
        return $data;   
    }
     
	// --------------------------------------------------------------------
 
 	/**
	 * Crée le fichier contenant les données des paramètres du photorama
     *
     * @access public 
	 * @param integer Identifiant du photorama (optionnel)
	 * @return boolean
	 */    
    public function create($file_id = 0)
    {
        $this -> set_file_path($file_id);    

        $params = $this -> _params; // Valeur par défaut       
                    
        return $this -> _write($params);            
    }
     
	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour le fichier contenant les données des paramètres du photorama
     *
     * @access public 
	 * @param array Tableau contenant les données du document à ajouter
	 * @return boolean
	 */    
    public function update($params)
    {
        settype($params, 'array');
        $this -> set_file_path($params['id']);
                           
        return $this -> _write($params);            
    }
    
	// --------------------------------------------------------------------
 
 	/**
	 * Supprime le fichier contenant les données des paramètres du photorama
     *
     * @access public 
	 * @param array Tableau contenant les identifiants des documents à supprimer
	 * @return void
	 */    
    public function delete($file_id = 0)
    {
        $this -> set_file_path($file_id);
        
        if (is_file($this -> _file_path)) {
            return @unlink($this -> _file_path);
        }
        
        return FALSE;   
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public function set_params_rules($params, $lang, $config)
    {        
        return array(
            'max_per_gal' => array( // Nombre maximum de miniatures par galerie
                array(
                    'rules' => array(array('Var_helper', 'is_digit_no_zero')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_number_valid'], ENT_QUOTES, 'UTF-8')
                ),
                array(
                    'rules' => array(array('Var_helper', 'is_digit_no_zero')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_number_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
            'width_max' => array( // Largeur maximum d'une miniature (en pixels)
                array(
                    'rules' => array(array('Var_helper', 'is_digit_no_zero')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_number_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
            'height_max' => array( // Hauteur maximum d'une miniature (en pixel)
                array(
                    'rules' => array(array('Var_helper', 'is_digit_no_zero')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_number_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
            'max_per_row' => array( // Nombre maximum de miniatures par ligne
                array(
                    'rules' => array(array('Var_helper', 'is_digit_no_zero')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_number_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
            'space' => array( // // Espace en pixels entre les miniatures
                array(
                    'rules' => array(array('Var_helper', 'is_digit')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_number_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
            'position' => array( // Position des miniatures L / C / R
                array(
                    'rules' => array(array('Var_helper', 'is_in_array[L,C,R]')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
            'display_mode' => array( // Mode d'affichage des diapos
                array(
                    'rules' => array(array('Var_helper', 'is_in_array[lightbox,lytebox]')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
            'delta_time' => array( // Intervalle entre diapos en secondes
                array(
                    'rules' => array(array('Var_helper', 'is_digit')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_number_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
            'slideshow' => array( // Inclure dans la boite slideshow on/off
                array(
                    'rules' => array(array('Var_helper', 'is_in_array[0,1]')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
            'free_gal' => array( // Galerie indépendante on/off
                array(
                    'rules' => array(array('Var_helper', 'is_in_array[0,1]')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
        );
    }

	// --------------------------------------------------------------------
 
	/**
	 * Lit et renvoie dans un tableau les données des documents enregistrées dans le fichier d'index
     * 
     * @access private 
	 * @return array Tableau contenant les données des documents enregistrées dans le fichier d'index
	 */
    private function _read()
    {
        global $param1, $param2, $param3, $param4, $param5, $param6, $param7, $param8, $param9, $param10;
        
        $data = array();        

        if (is_file($this -> _file_path)) {
            
            include $this -> _file_path;   
            
            $data = array(
                'max_per_gal'  => $param1,  // Nombre maximum de miniatures par galerie
                'width_max'    => $param2,  // Largeur maximum d'une miniature
                'height_max'   => $param3,  // Hauteur maximum d'une miniature
                'display_mode' => $param4,  // Choix effet pour le photorama
                'delta_time'   => $param5,  // Intervalle entre diapos en secondes
                'max_per_row'  => $param6,  // Nombre maximum de miniatures par ligne
                'space'        => $param7,  // Espace en pixels entre les miniatures
                'position'     => $param8,  // Position des miniatures L / C / R
                'slideshow'    => $param9,  // Inclure dans la boite slideshow on/off
                'free_gal'     => $param10, // Galerie indépendante on/off
            );
        }
        
        return $data;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Ecrit les données du document dans un fichier (écrasement des données existantes dans le fichier)
     * 
     * @access private
     * @param  array données du document à enregistrer
	 * @return boolean
	 */    
    private function _write($data)
    {
        settype($data, 'array');
        
        if (empty($this -> _file_path)) {
            return FALSE;
        }
        
        $data = $this -> _clean($data);

        $contents = "<?php
if (stristr(\$_SERVER[\"SCRIPT_NAME\"], \"params_".$this -> _file_id.".inc\")) {
    header(\"location:../index.php\");
    die();
}

\$param1  = stripslashes('".(int)$data['max_per_gal']."'); // Nombre maximum de miniatures par galerie
\$param2  = stripslashes('".(int)$data['width_max']."');   // Largeur maximum d'une miniature
\$param3  = stripslashes('".(int)$data['height_max']."');  // Hauteur maximum d'une miniature
\$param4  = stripslashes('".$data['display_mode']."');     // Mode d'affichage pour le photorama
\$param5  = stripslashes('".(int)$data['delta_time']."');  // Intervalle entre diapos en secondes
\$param6  = stripslashes('".(int)$data['max_per_row']."'); // Nombre maximum de miniatures par ligne
\$param7  = stripslashes('".(int)$data['space']."');       // Espace en pixels entre les miniatures
\$param8  = stripslashes('".$data['position']."');         // Position des miniatures L / C / R
\$param9  = stripslashes('".$data['slideshow']."');        // Inclure dans le slideshow on/off
\$param10 = stripslashes('".$data['free_gal']."');         // Galerie indépendante on/off
";
        WriteFullDB($this -> _file_path, $contents);
        
        return TRUE;        
    }

	// --------------------------------------------------------------------
  
	/**
	 * Nettoie les données du rédacteur
     * 
     * @access private 
	 * @param array Données du rédacteur à nettoyer
	 * @return array
	 */        
    private function _clean($data)
    {
        $data_by_default = $this -> _params;
        
        return array_merge($data_by_default, array_intersect_key($data, $data_by_default));
    }
 
	// --------------------------------------------------------------------

} // End of Class